=======
History
=======


0.15.0 (2019-07-30)
-------------------

* CitizenAPI class methods renamed to "private", they are intended to be used internally.
* TODO: None of the Citizen class's methods should return Response object - CitizenAPI is meant for that.


0.14.4 (2019-07-23)
-------------------

* Wall post comment endpoints updated with comment create endpoints.

0.1.0 (2019-07-19)
------------------

* First release on PyPI.
